ReadoutStyle class final
How a game wants its readouts drawn.
Constructors
- ReadoutStyle({TextStyle text = const TextStyle(color: Color(0xFFFFFFFF), fontSize: 18.0), Color dim = const Color(0x66FFFFFF)})
-
const
Properties
- dim → Color
-
The
/ 3half of "1 / 3", and anything the driver is not being asked to look at at two hundred kilometres an hour.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → TextStyle
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited